==> virtu-crud-1.1.0.tgz: package/index.js <==
// Author: Jean-Philippe Beaudet @ S3R3NITY Technology 
//
// Virtuba crud router
// CRUD
//
// Version : 1.0.0
// Copyrigths S3R3NITY Technologies.
//
//========================================================

// dependencies
var aes256 = require('aes256')
var config = require("./config.js");
var md5 = require('js-md5');
var fs = require('fs')
// globals
var TMP_FILE = config.tmp_file
var PASSPHRASE = config.passphrase
// setup openpgp
var openpgp = require('openpgp'); // use as CommonJS, AMD, ES6 module or via window.openpgp
	openpgp.initWorker({ path:'openpgp.worker.js' }) // set the relative web worker path
	openpgp.config.aead_protect = true // activate fast AES-GCM mode (not yet OpenPGP standard)
var options, encrypted;
// manage keys
var pubkey ;
fs.readFile('./key.pub', (err, data) => {
	if (err) throw err;
	pubkey =data
});
// generate a new private key helper method
function generate_keys(callback){
	var options = {
		userIds: [{ name:'jpbeaudet', email:'jpbeaudet@s3r3nity.com' }], // multiple user IDs
		numBits: 4096,                                            // RSA key size
		passphrase: PASSPHRASE         // protects the private key
	};
	openpgp.generateKey(options).then(function(key) {
		var privkey = key.privateKeyArmored; // '-----BEGIN PGP PRIVATE KEY BLOCK ... '
		//var pubkey = key.publicKeyArmored;   // '-----BEGIN PGP PUBLIC KEY BLOCK ... '
		callback(privkey)
	});
}
// private encrypting helper method
function encrypt_json(msg, callback){
	// generate a private key
	generate_keys(function(privkey){
	var passphrase = PASSPHRASE
	var privKeyObj = openpgp.key.readArmored(privkey).keys[0];
	privKeyObj.decrypt(passphrase);
	options = {
		data: msg,                             // input as String (or Uint8Array)
		publicKeys: openpgp.key.readArmored(pubkey).keys, // for encryption
		privateKeys: privKeyObj // for signing (optional)
	};
	openpgp.encrypt(options).then(function(ciphertext) {
		encrypted = ciphertext.data; // '-----BEGIN PGP MESSAGE ... END PGP MESSAGE-----'
		callback(ciphertext.data)
	});
	})
}
// command file queue 
var queue = {
	username_hash: null,
	tmpfolder : TMP_FILE,
	actions:{
		create : [],
		read: [],
		update: [],
		destroy: []
	}
}
// Main Module
module.exports = {
	// any text to md5 async
	toHash_async : function(msg, callback){
		md5(msg);
		var hash = md5.create();
		callback(null, hash.hex());
		}, 
	// any text to md5
	toHash : function(msg){
		md5(msg);
		var hash = md5.create();
		return(hash.hex());
		}, 
	// crud function
		// add action in the queue
		add : {
			// create (old[or empty], new)
			create : function(old_name, new_name){
				 queue.actions.create.push([old_name, new_name])
				 //console.log(queue)
				 return queue
			},
			// read (target)
			read : function(target){
				queue.actions.read.push(target)
				return queue
			},
			// update (old, new)
			update : function(old_name, new_name){
				queue.actions.update.push([old_name, new_name])
				return queue
			},
			// delete (target)
			destroy : function(target){
				queue.actions.destroy.push(target)
				return queue
			},
		},
		// remove all actions from the queue 
		refresh : function(callback){
			queue = {
				username_hash: null,
				tmpfolder : TMP_FILE,
				actions:{
					create : [],
					read: [],
					update: [],
					destroy: []
				}
			}
			callback(queue)
		},
	// send command file(map_to_push, callback(err, map, data))
		send : function(username_hash, map_to_push, callback){

			// complete json
			queue.username_hash = username_hash
			queue.map = TMP_FILE+'/'+username_hash+'.txt'
			// encrypt json
			var plaintext = JSON.stringify(queue);
			encrypt_json(plaintext, function(encrypted){
				// copy json to target tmp file
				fs.writeFile(TMP_FILE+'/'+username_hash+'.json', encrypted , (err) => {
					if (err) {throw err;}
					console.log(cmd_id+' command.json file is saved in '+TMP_FILE+'/'+username_hash+'.json');
				});
				fs.writeFile(TMP_FILE+'/'+username_hash+'.txt', map_to_push, (err) => {
					if (err) {throw err;}
					this.refresh(function(){
						return callback(null)
					})
				});
			})
		
}
}

==> virtu-crud-1.1.2.tgz: package/index.js <==
// Author: Jean-Philippe Beaudet @ S3R3NITY Technology 
//
// Virtuba crud router
// CRUD
//
// Version : 1.0.0
// Copyrigths S3R3NITY Technologies.
//
//========================================================

// dependencies
var aes256 = require('aes256')
var config = require("./config.js");
var md5 = require('js-md5');
var fs = require('fs')
// globals
var TMP_FILE = config.tmp_file
var PASSPHRASE = config.passphrase
// setup openpgp
var openpgp = require('openpgp'); // use as CommonJS, AMD, ES6 module or via window.openpgp
	openpgp.initWorker({ path:'openpgp.worker.js' }) // set the relative web worker path
	openpgp.config.aead_protect = true // activate fast AES-GCM mode (not yet OpenPGP standard)
var options, encrypted;
// manage keys
var pubkey ;
fs.readFile('./key.pub', (err, data) => {
	if (err) throw err;
	pubkey =data
});
// generate a new private key helper method
function generate_keys(callback){
	var options = {
		userIds: [{ name:'jpbeaudet', email:'jpbeaudet@s3r3nity.com' }], // multiple user IDs
		numBits: 4096,                                            // RSA key size
		passphrase: PASSPHRASE         // protects the private key
	};
	openpgp.generateKey(options).then(function(key) {
		var privkey = key.privateKeyArmored; // '-----BEGIN PGP PRIVATE KEY BLOCK ... '
		//var pubkey = key.publicKeyArmored;   // '-----BEGIN PGP PUBLIC KEY BLOCK ... '
		callback(privkey)
	});
}
// private encrypting helper method
function encrypt_json(msg, callback){
	// generate a private key
	generate_keys(function(privkey){
	var passphrase = PASSPHRASE
	var privKeyObj = openpgp.key.readArmored(privkey).keys[0];
	privKeyObj.decrypt(passphrase);
	options = {
		data: msg,                             // input as String (or Uint8Array)
		publicKeys: openpgp.key.readArmored(pubkey).keys, // for encryption
		privateKeys: privKeyObj // for signing (optional)
	};
	openpgp.encrypt(options).then(function(ciphertext) {
		encrypted = ciphertext.data; // '-----BEGIN PGP MESSAGE ... END PGP MESSAGE-----'
		callback(ciphertext.data)
	});
	})
}
// command file queue 
var queue = {
	username_hash: null,
	tmpfolder : TMP_FILE,
	actions:{
		create : [],
		read: [],
		update: [],
		destroy: []
	}
}
// Main Module
module.exports = {
	// any text to md5 async
	toHash_async : function(msg, callback){
		md5(msg);
		var hash = md5.create();
		callback(null, hash.hex());
		}, 
	// any text to md5
	toHash : function(msg){
		md5(msg);
		var hash = md5.create();
		return(hash.hex());
		}, 
	// crud function
		// add action in the queue
		add : {
			// create (old[or empty], new)
			create : function(old_name, new_name){
				 queue.actions.create.push([old_name, new_name])
				 //console.log(queue)
				 return queue
			},
			// read (target)
			read : function(target){
				queue.actions.read.push(target)
				return queue
			},
			// update (old, new)
			update : function(old_name, new_name){
				queue.actions.update.push([old_name, new_name])
				return queue
			},
			// delete (target)
			destroy : function(target){
				queue.actions.destroy.push(target)
				return queue
			},
		},
		// remove all actions from the queue 
		refresh : function(callback){
			queue = {
				username_hash: null,
				tmpfolder : TMP_FILE,
				actions:{
					create : [],
					read: [],
					update: [],
					destroy: []
				}
			}
			callback(queue)
		},
	// send command file(map_to_push, callback(err, map, data))
		send : function(username_hash, map_to_push, callback){

			// complete json
			queue.username_hash = username_hash
			queue.map = TMP_FILE+'/'+username_hash+'.txt'
			// encrypt json
			var plaintext = JSON.stringify(queue);
			encrypt_json(plaintext, function(encrypted){
				var options = {
					encoding: "ASCII"
				}
				// copy json to target tmp file
				fs.writeFile(TMP_FILE+'/'+username_hash+'.json', encrypted , options, (err) => {
					if (err) {throw err;}
					console.log(cmd_id+' command.json file is saved in '+TMP_FILE+'/'+username_hash+'.json');
				});
				fs.writeFile(TMP_FILE+'/'+username_hash+'.txt', map_to_push, (err) => {
					if (err) {throw err;}
					this.refresh(function(){
						return callback(null)
					})
				});
			})
		
}
}
